package com.enteprise.base_data_month.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.base_data_month.domain.EnterpriseBaseDataMonth;
import com.enteprise.base_data_month.service.IEnterpriseBaseDataMonthService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * base_data_monthController
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/base_data_month/base_data_month")
public class EnterpriseBaseDataMonthController extends BaseController
{
    @Autowired
    private IEnterpriseBaseDataMonthService enterpriseBaseDataMonthService;

    /**
     * 查询base_data_month列表
     */
    @PreAuthorize("@ss.hasPermi('base_data_month:base_data_month:list')")
    @GetMapping("/list")
    public TableDataInfo list(EnterpriseBaseDataMonth enterpriseBaseDataMonth)
    {
        startPage();
        List<EnterpriseBaseDataMonth> list = enterpriseBaseDataMonthService.selectEnterpriseBaseDataMonthList(enterpriseBaseDataMonth);
        return getDataTable(list);
    }

    /**
     * 导出base_data_month列表
     */
    @PreAuthorize("@ss.hasPermi('base_data_month:base_data_month:export')")
    @Log(title = "base_data_month", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EnterpriseBaseDataMonth enterpriseBaseDataMonth)
    {
        List<EnterpriseBaseDataMonth> list = enterpriseBaseDataMonthService.selectEnterpriseBaseDataMonthList(enterpriseBaseDataMonth);
        ExcelUtil<EnterpriseBaseDataMonth> util = new ExcelUtil<EnterpriseBaseDataMonth>(EnterpriseBaseDataMonth.class);
        util.exportExcel(response, list, "base_data_month数据");
    }

    /**
     * 获取base_data_month详细信息
     */
    @PreAuthorize("@ss.hasPermi('base_data_month:base_data_month:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseBaseDataMonthService.selectEnterpriseBaseDataMonthById(id));
    }

    /**
     * 新增base_data_month
     */
    @PreAuthorize("@ss.hasPermi('base_data_month:base_data_month:add')")
    @Log(title = "base_data_month", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EnterpriseBaseDataMonth enterpriseBaseDataMonth)
    {
        return toAjax(enterpriseBaseDataMonthService.insertEnterpriseBaseDataMonth(enterpriseBaseDataMonth));
    }

    /**
     * 修改base_data_month
     */
    @PreAuthorize("@ss.hasPermi('base_data_month:base_data_month:edit')")
    @Log(title = "base_data_month", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EnterpriseBaseDataMonth enterpriseBaseDataMonth)
    {
        return toAjax(enterpriseBaseDataMonthService.updateEnterpriseBaseDataMonth(enterpriseBaseDataMonth));
    }

    /**
     * 删除base_data_month
     */
    @PreAuthorize("@ss.hasPermi('base_data_month:base_data_month:remove')")
    @Log(title = "base_data_month", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseBaseDataMonthService.deleteEnterpriseBaseDataMonthByIds(ids));
    }
}
