package com.enteprise.base_data_year.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.base_data_year.domain.EnterpriseBaseDataYear;
import com.enteprise.base_data_year.service.IEnterpriseBaseDataYearService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * base_data_yearController
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/base_data_year/base_data_year")
public class EnterpriseBaseDataYearController extends BaseController
{
    @Autowired
    private IEnterpriseBaseDataYearService enterpriseBaseDataYearService;

    /**
     * 查询base_data_year列表
     */
    @PreAuthorize("@ss.hasPermi('base_data_year:base_data_year:list')")
    @GetMapping("/list")
    public TableDataInfo list(EnterpriseBaseDataYear enterpriseBaseDataYear)
    {
        startPage();
        List<EnterpriseBaseDataYear> list = enterpriseBaseDataYearService.selectEnterpriseBaseDataYearList(enterpriseBaseDataYear);
        return getDataTable(list);
    }

    /**
     * 导出base_data_year列表
     */
    @PreAuthorize("@ss.hasPermi('base_data_year:base_data_year:export')")
    @Log(title = "base_data_year", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EnterpriseBaseDataYear enterpriseBaseDataYear)
    {
        List<EnterpriseBaseDataYear> list = enterpriseBaseDataYearService.selectEnterpriseBaseDataYearList(enterpriseBaseDataYear);
        ExcelUtil<EnterpriseBaseDataYear> util = new ExcelUtil<EnterpriseBaseDataYear>(EnterpriseBaseDataYear.class);
        util.exportExcel(response, list, "base_data_year数据");
    }

    /**
     * 获取base_data_year详细信息
     */
    @PreAuthorize("@ss.hasPermi('base_data_year:base_data_year:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseBaseDataYearService.selectEnterpriseBaseDataYearById(id));
    }

    /**
     * 新增base_data_year
     */
    @PreAuthorize("@ss.hasPermi('base_data_year:base_data_year:add')")
    @Log(title = "base_data_year", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EnterpriseBaseDataYear enterpriseBaseDataYear)
    {
        return toAjax(enterpriseBaseDataYearService.insertEnterpriseBaseDataYear(enterpriseBaseDataYear));
    }

    /**
     * 修改base_data_year
     */
    @PreAuthorize("@ss.hasPermi('base_data_year:base_data_year:edit')")
    @Log(title = "base_data_year", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EnterpriseBaseDataYear enterpriseBaseDataYear)
    {
        return toAjax(enterpriseBaseDataYearService.updateEnterpriseBaseDataYear(enterpriseBaseDataYear));
    }

    /**
     * 删除base_data_year
     */
    @PreAuthorize("@ss.hasPermi('base_data_year:base_data_year:remove')")
    @Log(title = "base_data_year", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseBaseDataYearService.deleteEnterpriseBaseDataYearByIds(ids));
    }
}
