package com.enteprise.enterprise.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.enteprise.enterprise.dto.EnterpriseDto;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.enterprise.domain.Enterprise;
import com.enteprise.enterprise.service.IEnterpriseService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * enterpriseController
 *
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/enterprise/enterprise")
public class EnterpriseController extends BaseController
{
    @Autowired
    private IEnterpriseService enterpriseService;

    /**
     * 查询enterprise列表
     */
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:list')")
    @GetMapping("/list")
    public TableDataInfo list(Enterprise enterprise)
    {
        startPage();
        List<Enterprise> list = enterpriseService.selectEnterpriseList(enterprise);
        return getDataTable(list);
    }

    /**
     * 查询enterprise列表
     */
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:list')")
    @GetMapping("/tlist")
    public TableDataInfo listWithType(Enterprise enterprise)
    {
        startPage();
        List<EnterpriseDto> list = enterpriseService.selectAllWithType(enterprise);
        return getDataTable(list);
    }

    /**
     * 导出enterprise列表
     */
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:export')")
    @Log(title = "enterprise", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Enterprise enterprise)
    {
        List<Enterprise> list = enterpriseService.selectEnterpriseList(enterprise);
        ExcelUtil<Enterprise> util = new ExcelUtil<Enterprise>(Enterprise.class);
        util.exportExcel(response, list, "enterprise数据");
    }

    /**
     * 获取enterprise详细信息
     */
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseService.selectEnterpriseById(id));
    }

    /**
     * 新增enterprise
     */
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:add')")
    @Log(title = "enterprise", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Enterprise enterprise)
    {
        return toAjax(enterpriseService.insertEnterprise(enterprise));
    }

    /**
     * 修改enterprise
     */
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:edit')")
    @Log(title = "enterprise", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Enterprise enterprise)
    {
        return toAjax(enterpriseService.updateEnterprise(enterprise));
    }

    /**
     * 删除enterprise
     */
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:remove')")
    @Log(title = "enterprise", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseService.deleteEnterpriseByIds(ids));
    }

    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:alllist')")
    @GetMapping("/alllist")
    public TableDataInfo alllist(Enterprise enterprise)
    {
        List<Enterprise> list = enterpriseService.selectEnterpriseList(enterprise);
        return getDataTable(list);
    }

    /**
     * 导入
     */
    @ApiOperation("导入企业实体（分类）数据")
    @Log(title = "企业信息", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('enterprise:enterprise:add')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file) {
        try {
            // 获取模板工具
            ExcelUtil<EnterpriseDto> util = new ExcelUtil<>(EnterpriseDto.class);
            List<EnterpriseDto> list = util.importExcel(file.getInputStream());
            if (list.isEmpty()) {
                return error("数据不得为空");
            }
            // 调用服务层进行插入或更新
            int successCount = enterpriseService.insertOrUpdateBatch(list);
            return AjaxResult.success("导入成功，共处理 " + successCount + " 条数据");
        } catch (Exception e) {
            return AjaxResult.error("导入失败：" + e.getMessage());
        }
    }

    @ApiOperation("企业实体（分类）模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<EnterpriseDto> util = new ExcelUtil<>(EnterpriseDto.class);
        util.importTemplateExcel(response, "企业实体（分类）数据");
    }

}
