package com.enteprise.enterprise.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Collectors;

import com.enteprise.enterprise.dto.EnterpriseDto;
import com.enteprise.etype.domain.EnterpriseType;
import com.enteprise.etype.mapper.EnterpriseTypeMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.enteprise.enterprise.mapper.EnterpriseMapper;
import com.enteprise.enterprise.domain.Enterprise;
import com.enteprise.enterprise.service.IEnterpriseService;

/**
 * enterpriseService业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
@Service
public class EnterpriseServiceImpl implements IEnterpriseService 
{
    @Autowired
    private EnterpriseMapper enterpriseMapper;

    @Autowired
    private EnterpriseTypeMapper enterpriseTypeMapper;

    /**
     * 查询enterprise
     * 
     * @param id enterprise主键
     * @return enterprise
     */
    @Override
    public EnterpriseDto selectEnterpriseById(Long id)
    {
        return enterpriseMapper.selectEnterpriseById(id);
    }

    /**
     * 查询enterprise列表
     * 
     * @param enterprise enterprise
     * @return enterprise
     */
    @Override
    public List<Enterprise> selectEnterpriseList(Enterprise enterprise)
    {
        return enterpriseMapper.selectEnterpriseList(enterprise);
    }

    @Override
    public List<EnterpriseDto> selectAllWithType(Enterprise enterprise) {
        return enterpriseMapper.selectAllWithType(enterprise);
    }

    /**
     * 新增enterprise
     * 
     * @param enterprise enterprise
     * @return 结果
     */
    @Override
    public int insertEnterprise(Enterprise enterprise)
    {
        return enterpriseMapper.insertEnterprise(enterprise);
    }

    /**
     * 修改enterprise
     * 
     * @param enterprise enterprise
     * @return 结果
     */
    @Override
    public int updateEnterprise(Enterprise enterprise)
    {
        return enterpriseMapper.updateEnterprise(enterprise);
    }

    /**
     * 批量删除enterprise
     * 
     * @param ids 需要删除的enterprise主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseByIds(Long[] ids)
    {
        return enterpriseMapper.deleteEnterpriseByIds(ids);
    }

    /**
     * 删除enterprise信息
     * 
     * @param id enterprise主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseById(Long id)
    {
        return enterpriseMapper.deleteEnterpriseById(id);
    }

    @Override
    public int insertOrUpdateBatch(List<EnterpriseDto> list) {
        int i = 0;
        //获取导入分类表的数据
        List<EnterpriseType> typesToInsertOrUpdate = new ArrayList<>();
        for (EnterpriseDto entity : list) {
            String typeNumber = entity.getTypeNum();
            String typeName = entity.getTypeName();
            if (typeNumber != null && typeName != null) {
                // 检查已有列表中是否已经有此 typeNumber
                Optional<EnterpriseType> existingType = typesToInsertOrUpdate.stream()
                        .filter(t -> t.getNumber().equals(typeNumber))
                        .findFirst();

                if (!existingType.isPresent()) {
                    // 不存在则添加新的 Type 到列表中
                    EnterpriseType newType = new EnterpriseType();
                    newType.setNumber(typeNumber);
                    newType.setName(typeName);
                    typesToInsertOrUpdate.add(newType);
                }
            }
        }
        //导入分类表
        if (!typesToInsertOrUpdate.isEmpty()) {
            enterpriseTypeMapper.insertBatch(typesToInsertOrUpdate);
        }
        //导入企业表
        if (!list.isEmpty()) {
            i = enterpriseMapper.insertOrUpdateBatch(list);
        }
        return i;
    }
}
