package com.enteprise.etype.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.etype.domain.EnterpriseType;
import com.enteprise.etype.service.IEnterpriseTypeService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * etypeController
 * 
 * @author ljx
 * @date 2025-02-07
 */
@RestController
@RequestMapping("/etype/etype")
public class EnterpriseTypeController extends BaseController
{
    @Autowired
    private IEnterpriseTypeService enterpriseTypeService;

    /**
     * 查询etype列表
     */
    @PreAuthorize("@ss.hasPermi('etype:etype:list')")
    @GetMapping("/list")
    public TableDataInfo list(EnterpriseType enterpriseType)
    {
        startPage();
        List<EnterpriseType> list = enterpriseTypeService.selectEnterpriseTypeList(enterpriseType);
        return getDataTable(list);
    }

    /**
     * 导出etype列表
     */
    @PreAuthorize("@ss.hasPermi('etype:etype:export')")
    @Log(title = "etype", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EnterpriseType enterpriseType)
    {
        List<EnterpriseType> list = enterpriseTypeService.selectEnterpriseTypeList(enterpriseType);
        ExcelUtil<EnterpriseType> util = new ExcelUtil<EnterpriseType>(EnterpriseType.class);
        util.exportExcel(response, list, "etype数据");
    }

    /**
     * 获取etype详细信息
     */
    @PreAuthorize("@ss.hasPermi('etype:etype:query')")
    @GetMapping(value = "/{number}")
    public AjaxResult getInfo(@PathVariable("number") String number)
    {
        return success(enterpriseTypeService.selectEnterpriseTypeByNumber(number));
    }

    /**
     * 新增etype
     */
    @PreAuthorize("@ss.hasPermi('etype:etype:add')")
    @Log(title = "etype", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EnterpriseType enterpriseType)
    {
        return toAjax(enterpriseTypeService.insertEnterpriseType(enterpriseType));
    }

    /**
     * 修改etype
     */
    @PreAuthorize("@ss.hasPermi('etype:etype:edit')")
    @Log(title = "etype", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EnterpriseType enterpriseType)
    {
        return toAjax(enterpriseTypeService.updateEnterpriseType(enterpriseType));
    }

    /**
     * 删除etype
     */
    @PreAuthorize("@ss.hasPermi('etype:etype:remove')")
    @Log(title = "etype", businessType = BusinessType.DELETE)
	@DeleteMapping("/{numbers}")
    public AjaxResult remove(@PathVariable String[] numbers)
    {
        System.out.println("");
        return toAjax(enterpriseTypeService.deleteEnterpriseTypeByNumbers(numbers));
    }

    /**
     * 导入
     */
    @ApiOperation("导入企业分类")
    @Log(title = "资产信息", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('etype:etype:add')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file) throws Exception {
        // 获取模板工具
        ExcelUtil<EnterpriseType> util = new ExcelUtil<>(EnterpriseType.class);
        List<EnterpriseType> tbEnterpriseType = util.importExcel(file.getInputStream());
        if (tbEnterpriseType.isEmpty()) {
            return error("数据不得为空");
        }
        boolean result = enterpriseTypeService.batchTbEnterpriseType(tbEnterpriseType);
        return result ? success() : error();
    }

    @ApiOperation("企业分类模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<EnterpriseType> util = new ExcelUtil<>(EnterpriseType.class);
        util.importTemplateExcel(response, "企业分类数据");
    }
}
