package com.enteprise.etype.service.impl;

import java.util.List;

import com.enteprise.common.core.domain.entity.SysDept;
import com.enteprise.system.mapper.SysDeptMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.enteprise.etype.mapper.EnterpriseTypeMapper;
import com.enteprise.etype.domain.EnterpriseType;
import com.enteprise.etype.service.IEnterpriseTypeService;

import javax.annotation.Resource;

/**
 * etypeService业务层处理
 * 
 * @author ljx
 * @date 2025-02-07
 */
@Service
public class EnterpriseTypeServiceImpl implements IEnterpriseTypeService 
{
    @Autowired
    private EnterpriseTypeMapper enterpriseTypeMapper;

    @Resource
    private SysDeptMapper sysDeptMapper;

    /**
     * 查询etype
     * 
     * @param number etype主键
     * @return etype
     */
    @Override
    public EnterpriseType selectEnterpriseTypeByNumber(String number)
    {
        return enterpriseTypeMapper.selectEnterpriseTypeByNumber(number);
    }

    /**
     * 查询etype列表
     * 
     * @param enterpriseType etype
     * @return etype
     */
    @Override
    public List<EnterpriseType> selectEnterpriseTypeList(EnterpriseType enterpriseType)
    {
        return enterpriseTypeMapper.selectEnterpriseTypeList(enterpriseType);
    }

    /**
     * 新增etype
     * 
     * @param enterpriseType etype
     * @return 结果
     */
    @Override
    public int insertEnterpriseType(EnterpriseType enterpriseType)
    {
        // 1. 校验数据（例如检查分类编码是否重复）

        if (enterpriseType.getNumber() == null || enterpriseType.getName() == null) {
            throw new RuntimeException("分类编码或名称为空！");
        }
        // 检查数据库是否已存在相同编码
        EnterpriseType exist = enterpriseTypeMapper.selectEnterpriseTypeByNumber(enterpriseType.getNumber());
        if (exist != null) {
            throw new RuntimeException("分类编码 " + enterpriseType.getNumber() + " 已存在！");
        }

        return enterpriseTypeMapper.insertEnterpriseType(enterpriseType);
    }

    @Override
    public boolean batchTbEnterpriseType(List<EnterpriseType> tbEnterpriseType) {
        // 2. 批量插入数据库
        enterpriseTypeMapper.insertBatch(tbEnterpriseType);
        return true;
    }

    /**
     * 修改etype
     * 
     * @param enterpriseType etype
     * @return 结果
     */
    @Override
    public int updateEnterpriseType(EnterpriseType enterpriseType)
    {
        return enterpriseTypeMapper.updateEnterpriseType(enterpriseType);
    }

    /**
     * 批量删除etype
     * 
     * @param numbers 需要删除的etype主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseTypeByNumbers(String[] numbers)
    {
        return enterpriseTypeMapper.deleteEnterpriseTypeByNumbers(numbers);
    }

    /**
     * 删除etype信息
     * 
     * @param number etype主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseTypeByNumber(String number)
    {
        return enterpriseTypeMapper.deleteEnterpriseTypeByNumber(number);
    }
}
