package com.enteprise.industry.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.industry.domain.Industry;
import com.enteprise.industry.service.IIndustryService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * industryController
 *
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/industry/industry")
public class IndustryController extends BaseController
{
    @Autowired
    private IIndustryService industryService;

    /**
     * 查询industry列表
     */
    @PreAuthorize("@ss.hasPermi('industry:industry:list')")
    @GetMapping("/list")
    public TableDataInfo list(Industry industry)
    {
        startPage();
        List<Industry> list = industryService.selectIndustryList(industry);
        return getDataTable(list);
    }

    /**
     * 导出industry列表
     */
    @PreAuthorize("@ss.hasPermi('industry:industry:export')")
    @Log(title = "industry", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Industry industry)
    {
        List<Industry> list = industryService.selectIndustryList(industry);
        ExcelUtil<Industry> util = new ExcelUtil<Industry>(Industry.class);
        util.exportExcel(response, list, "industry数据");
    }

    /**
     * 获取industry详细信息
     */
    @PreAuthorize("@ss.hasPermi('industry:industry:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(industryService.selectIndustryById(id));
    }

    /**
     * 新增industry
     */
    @PreAuthorize("@ss.hasPermi('industry:industry:add')")
    @Log(title = "industry", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Industry industry)
    {
        return toAjax(industryService.insertIndustry(industry));
    }

    /**
     * 修改industry
     */
    @PreAuthorize("@ss.hasPermi('industry:industry:edit')")
    @Log(title = "industry", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Industry industry)
    {
        return toAjax(industryService.updateIndustry(industry));
    }

    /**
     * 删除industry
     */
    @PreAuthorize("@ss.hasPermi('industry:industry:remove')")
    @Log(title = "industry", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(industryService.deleteIndustryByIds(ids));
    }

    @PreAuthorize("@ss.hasPermi('industry:industry:alllist')")
    @GetMapping("/alllist")
    public TableDataInfo alllist(Industry industry)
    {
        List<Industry> list = industryService.selectIndustryList(industry);
        return getDataTable(list);
    }
}
