package com.enteprise.industry_oveview.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.enteprise.industry_oveview.domain.IndustryCount;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.industry_oveview.domain.IndustryOverview;
import com.enteprise.industry_oveview.service.IIndustryOverviewService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * industry_oveviewController
 * 
 * @author ruoyi
 * @date 2024-11-11
 */
@RestController
@RequestMapping("/industry_oveview/industry_oveview")
public class IndustryOverviewController extends BaseController
{
    @Autowired
    private IIndustryOverviewService industryOverviewService;

    /**
     * 查询industry_oveview列表
     */
    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:list')")
    @GetMapping("/list")
    public TableDataInfo list(IndustryOverview industryOverview)
    {

        startPage();
        List<IndustryOverview> industryOverviews = industryOverviewService.selectIndustryOverviewList(industryOverview);
        return getDataTable(industryOverviews);
    }

    /**
     * 查询行业数量列表
     */
    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:list')")
    @GetMapping("/i_list")
    public TableDataInfo iList()
    {
        //startPage();
        List<IndustryCount> list = industryOverviewService.selectIndustryCountList();
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:list')")
    @GetMapping("/i_all_list")
    public TableDataInfo iAllList()
    {
        //startPage();
        List<IndustryCount> list = industryOverviewService.countAllIndustries();
        return getDataTable(list);
    }

    /**
     * 导出industry_oveview列表
     */
    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:export')")
    @Log(title = "industry_oveview", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, IndustryOverview industryOverview)
    {
        List<IndustryOverview> list = industryOverviewService.selectIndustryOverviewList(industryOverview);
        ExcelUtil<IndustryOverview> util = new ExcelUtil<IndustryOverview>(IndustryOverview.class);
        util.exportExcel(response, list, "industry_oveview数据");
    }

    /**
     * 获取industry_oveview详细信息
     */
    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(industryOverviewService.selectIndustryOverviewById(id));
    }

    /**
     * 新增industry_oveview
     */
    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:add')")
    @Log(title = "industry_oveview", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody IndustryOverview industryOverview)
    {
        return toAjax(industryOverviewService.insertIndustryOverview(industryOverview));
    }

    /**
     * 修改industry_oveview
     */
    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:edit')")
    @Log(title = "industry_oveview", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody IndustryOverview industryOverview)
    {
        return toAjax(industryOverviewService.updateIndustryOverview(industryOverview));
    }

    /**
     * 删除industry_oveview
     */
    @PreAuthorize("@ss.hasPermi('industry_oveview:industry_oveview:remove')")
    @Log(title = "industry_oveview", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(industryOverviewService.deleteIndustryOverviewByIds(ids));
    }
}
