package com.enteprise.industry_oveview.service.impl;

import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

import com.enteprise.enterprise.domain.Enterprise;
import com.enteprise.enterprise.mapper.EnterpriseMapper;
import com.enteprise.industry_oveview.domain.IndustryCount;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.enteprise.industry_oveview.mapper.IndustryOverviewMapper;
import com.enteprise.industry_oveview.domain.IndustryOverview;
import com.enteprise.industry_oveview.service.IIndustryOverviewService;

/**
 * industry_oveviewService业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-11
 */
@Service
public class IndustryOverviewServiceImpl implements IIndustryOverviewService 
{
    @Autowired
    private IndustryOverviewMapper industryOverviewMapper;

    @Autowired
    private EnterpriseMapper enterpriseMapper;

    /**
     * 查询industry_oveview
     * 
     * @param id industry_oveview主键
     * @return industry_oveview
     */
    @Override
    public IndustryOverview selectIndustryOverviewById(Long id)
    {
        return industryOverviewMapper.selectIndustryOverviewById(id);
    }

    /**
     * 查询industry_oveview列表
     * 
     * @param industryOverview industry_oveview
     * @return industry_oveview
     */
    @Override
    public List<IndustryOverview> selectIndustryOverviewList(IndustryOverview industryOverview)
    {
        List<IndustryOverview> list = new ArrayList<>();;
        if (industryOverview.getYear() == 0){
            //求总和
            IndustryOverview latestData = null;
            List<Integer> years = new ArrayList<>();;
            long sumPowerConsume = 0L;
            long sumEnergyConsume = 0L;
            long sumFunding = 0L;
            long sumTotalIndustrialValue = 0L;
            long sumTaxableIncome = 0L;
            long sumPaidTax = 0L;
            List<IndustryOverview> industryOverviews = industryOverviewMapper.selectIndustryOverviewList(industryOverview);
            for (IndustryOverview item : industryOverviews){
                //获取最新年份实体
                if (latestData  == null || item.getYear() > latestData .getYear()){
                    latestData  = item;
                }
                //统计数据
                sumPowerConsume += item.getPowerConsumeSum();
                sumEnergyConsume += item.getEnergyConsumeSum();
                sumFunding += item.getFundingSum();
                sumTotalIndustrialValue += item.getTotalIndustrialValueSum();
                sumTaxableIncome += item.getTaxableIncomeSum();
                sumPaidTax += item.getPaidTaxSum();
                years.add(item.getYear());
                // 替换最新数据
                if (latestData != null) {
                    latestData.setYears(years);
                    latestData.setPowerConsumeSum(sumPowerConsume);
                    latestData.setEnergyConsumeSum(sumEnergyConsume);
                    latestData.setFundingSum(sumFunding);
                    latestData.setTotalIndustrialValueSum(sumTotalIndustrialValue);
                    latestData.setTaxableIncomeSum(sumTaxableIncome);
                    latestData.setPaidTaxSum(sumPaidTax);
                }
            }
            list.add(latestData);
        }else {
            //求某年
            list  = industryOverviewMapper.selectIndustryOverviewList(industryOverview);
        }
        return list;
    }

    @Override
    public List<IndustryCount> selectIndustryCountList() {
        //获取前十排名
        List<IndustryCount> collect = industryOverviewMapper.selectIndustryCount().stream().limit(10).collect(Collectors.toList());
        IndustryCount industryCount = new IndustryCount();
        //计算企业剩余数
        industryCount.setCode("others");
        industryCount.setIndustryName("其他");
        List<Enterprise> enterprises = enterpriseMapper.selectEnterpriseList(new Enterprise());
        int i = enterprises.size() + 1 - collect.stream().mapToInt(IndustryCount::getNumber).sum();
        industryCount.setNumber(i);
        //合并输出
        collect.add(industryCount);
        return collect;
    }

    @Override
    public List<IndustryCount> countAllIndustries() {
        List<IndustryCount> industryCounts = industryOverviewMapper.selectIndustryCount();
        //数量从小到大排
        return industryCounts.stream().sorted(Comparator.comparingInt(IndustryCount::getNumber))
                .collect(Collectors.toList());
    }

    /**
     * 新增industry_oveview
     * 
     * @param industryOverview industry_oveview
     * @return 结果
     */
    @Override
    public int insertIndustryOverview(IndustryOverview industryOverview)
    {
        return industryOverviewMapper.insertIndustryOverview(industryOverview);
    }

    /**
     * 修改industry_oveview
     * 
     * @param industryOverview industry_oveview
     * @return 结果
     */
    @Override
    public int updateIndustryOverview(IndustryOverview industryOverview)
    {
        return industryOverviewMapper.updateIndustryOverview(industryOverview);
    }

    /**
     * 批量删除industry_oveview
     * 
     * @param ids 需要删除的industry_oveview主键
     * @return 结果
     */
    @Override
    public int deleteIndustryOverviewByIds(Long[] ids)
    {
        return industryOverviewMapper.deleteIndustryOverviewByIds(ids);
    }

    /**
     * 删除industry_oveview信息
     * 
     * @param id industry_oveview主键
     * @return 结果
     */
    @Override
    public int deleteIndustryOverviewById(Long id)
    {
        return industryOverviewMapper.deleteIndustryOverviewById(id);
    }

}
