package com.enteprise.industry_run.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.industry_run.domain.EnterpriseBaseDataTotal;
import com.enteprise.industry_run.service.IEnterpriseBaseDataTotalService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * industry_runController
 *
 * @author ruoyi
 * @date 2024-11-13
 */
@RestController
@RequestMapping("/industry_run/industry_run")
public class EnterpriseBaseDataTotalController extends BaseController
{
    @Autowired
    private IEnterpriseBaseDataTotalService enterpriseBaseDataTotalService;

    /**
     * 查询industry_run列表
     */
    @PreAuthorize("@ss.hasPermi('industry_run:industry_run:list')")
    @GetMapping("/list")
    public TableDataInfo list(EnterpriseBaseDataTotal enterpriseBaseDataTotal)
    {
        startPage();
        List<EnterpriseBaseDataTotal> list = enterpriseBaseDataTotalService.selectEnterpriseBaseDataTotalList(enterpriseBaseDataTotal);
        return getDataTable(list);
    }

    /**
     * 导出industry_run列表
     */
    @PreAuthorize("@ss.hasPermi('industry_run:industry_run:export')")
    @Log(title = "industry_run", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EnterpriseBaseDataTotal enterpriseBaseDataTotal)
    {
        List<EnterpriseBaseDataTotal> list = enterpriseBaseDataTotalService.selectEnterpriseBaseDataTotalList(enterpriseBaseDataTotal);
        ExcelUtil<EnterpriseBaseDataTotal> util = new ExcelUtil<EnterpriseBaseDataTotal>(EnterpriseBaseDataTotal.class);
        util.exportExcel(response, list, "industry_run数据");
    }

    /**
     * 获取industry_run详细信息
     */
    @PreAuthorize("@ss.hasPermi('industry_run:industry_run:query')")
    @GetMapping(value = "/{enterpriseName}")
    public AjaxResult getInfo(@PathVariable("enterpriseName") String enterpriseName)
    {
        return success(enterpriseBaseDataTotalService.selectEnterpriseBaseDataTotalByEnterpriseName(enterpriseName));
    }

    /**
     * 新增industry_run
     */
    @PreAuthorize("@ss.hasPermi('industry_run:industry_run:add')")
    @Log(title = "industry_run", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EnterpriseBaseDataTotal enterpriseBaseDataTotal)
    {
        return toAjax(enterpriseBaseDataTotalService.insertEnterpriseBaseDataTotal(enterpriseBaseDataTotal));
    }

    /**
     * 修改industry_run
     */
    @PreAuthorize("@ss.hasPermi('industry_run:industry_run:edit')")
    @Log(title = "industry_run", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EnterpriseBaseDataTotal enterpriseBaseDataTotal)
    {
        return toAjax(enterpriseBaseDataTotalService.updateEnterpriseBaseDataTotal(enterpriseBaseDataTotal));
    }

    /**
     * 删除industry_run
     */
    @PreAuthorize("@ss.hasPermi('industry_run:industry_run:remove')")
    @Log(title = "industry_run", businessType = BusinessType.DELETE)
	@DeleteMapping("/{enterpriseNames}")
    public AjaxResult remove(@PathVariable String[] enterpriseNames)
    {
        return toAjax(enterpriseBaseDataTotalService.deleteEnterpriseBaseDataTotalByEnterpriseNames(enterpriseNames));
    }

    @PreAuthorize("@ss.hasPermi('industry_run:industry_run:alllist')")
    @GetMapping("/alllist")
    public TableDataInfo alllist(EnterpriseBaseDataTotal enterpriseBaseDataTotal)
    {
//        startPage();
        List<EnterpriseBaseDataTotal> list = enterpriseBaseDataTotalService.selectEnterpriseBaseDataTotalList(enterpriseBaseDataTotal);
        return getDataTable(list);
    }
}
