package com.enteprise.predict.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.predict.domain.Predict;
import com.enteprise.predict.service.IPredictService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * predictController
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/predict/predict")
public class PredictController extends BaseController
{
    @Autowired
    private IPredictService predictService;

    /**
     * 查询predict列表
     */
    @PreAuthorize("@ss.hasPermi('predict:predict:list')")
    @GetMapping("/list")
    public TableDataInfo list(Predict predict)
    {
        startPage();
        List<Predict> list = predictService.selectPredictList(predict);
        return getDataTable(list);
    }

    /**
     * 导出predict列表
     */
    @PreAuthorize("@ss.hasPermi('predict:predict:export')")
    @Log(title = "predict", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Predict predict)
    {
        List<Predict> list = predictService.selectPredictList(predict);
        ExcelUtil<Predict> util = new ExcelUtil<Predict>(Predict.class);
        util.exportExcel(response, list, "predict数据");
    }

    /**
     * 获取predict详细信息
     */
    @PreAuthorize("@ss.hasPermi('predict:predict:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(predictService.selectPredictById(id));
    }

    /**
     * 新增predict
     */
    @PreAuthorize("@ss.hasPermi('predict:predict:add')")
    @Log(title = "predict", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Predict predict)
    {
        return toAjax(predictService.insertPredict(predict));
    }

    /**
     * 修改predict
     */
    @PreAuthorize("@ss.hasPermi('predict:predict:edit')")
    @Log(title = "predict", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Predict predict)
    {
        return toAjax(predictService.updatePredict(predict));
    }

    /**
     * 删除predict
     */
    @PreAuthorize("@ss.hasPermi('predict:predict:remove')")
    @Log(title = "predict", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(predictService.deletePredictByIds(ids));
    }
}
