package com.enteprise.predictseason.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.predictseason.domain.Predictseason;
import com.enteprise.predictseason.service.IPredictseasonService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * predictseasonController
 * 
 * @author ruoyi
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/predictseason/predictseason")
public class PredictseasonController extends BaseController
{
    @Autowired
    private IPredictseasonService predictseasonService;

    /**
     * 查询predictseason列表
     */
    @PreAuthorize("@ss.hasPermi('predictseason:predictseason:list')")
    @GetMapping("/list")
    public TableDataInfo list(Predictseason predictseason)
    {
        startPage();
        List<Predictseason> list = predictseasonService.selectPredictseasonList(predictseason);
        return getDataTable(list);
    }

    /**
     * 导出predictseason列表
     */
    @PreAuthorize("@ss.hasPermi('predictseason:predictseason:export')")
    @Log(title = "predictseason", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Predictseason predictseason)
    {
        List<Predictseason> list = predictseasonService.selectPredictseasonList(predictseason);
        ExcelUtil<Predictseason> util = new ExcelUtil<Predictseason>(Predictseason.class);
        util.exportExcel(response, list, "predictseason数据");
    }

    /**
     * 获取predictseason详细信息
     */
    @PreAuthorize("@ss.hasPermi('predictseason:predictseason:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(predictseasonService.selectPredictseasonById(id));
    }

    /**
     * 新增predictseason
     */
    @PreAuthorize("@ss.hasPermi('predictseason:predictseason:add')")
    @Log(title = "predictseason", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Predictseason predictseason)
    {
        return toAjax(predictseasonService.insertPredictseason(predictseason));
    }

    /**
     * 修改predictseason
     */
    @PreAuthorize("@ss.hasPermi('predictseason:predictseason:edit')")
    @Log(title = "predictseason", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Predictseason predictseason)
    {
        return toAjax(predictseasonService.updatePredictseason(predictseason));
    }

    /**
     * 删除predictseason
     */
    @PreAuthorize("@ss.hasPermi('predictseason:predictseason:remove')")
    @Log(title = "predictseason", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(predictseasonService.deletePredictseasonByIds(ids));
    }
}
