package com.enteprise.predicttotal.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.predicttotal.domain.Predicttotal;
import com.enteprise.predicttotal.service.IPredicttotalService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * predicttotalController
 * 
 * @author ruoyi
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/predicttotal/predicttotal")
public class PredicttotalController extends BaseController
{
    @Autowired
    private IPredicttotalService predicttotalService;

    /**
     * 查询predicttotal列表
     */
    @PreAuthorize("@ss.hasPermi('predicttotal:predicttotal:list')")
    @GetMapping("/list")
    public TableDataInfo list(Predicttotal predicttotal)
    {
        startPage();
        List<Predicttotal> list = predicttotalService.selectPredicttotalList(predicttotal);
        return getDataTable(list);
    }

    /**
     * 导出predicttotal列表
     */
    @PreAuthorize("@ss.hasPermi('predicttotal:predicttotal:export')")
    @Log(title = "predicttotal", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Predicttotal predicttotal)
    {
        List<Predicttotal> list = predicttotalService.selectPredicttotalList(predicttotal);
        ExcelUtil<Predicttotal> util = new ExcelUtil<Predicttotal>(Predicttotal.class);
        util.exportExcel(response, list, "predicttotal数据");
    }

    /**
     * 获取predicttotal详细信息
     */
    @PreAuthorize("@ss.hasPermi('predicttotal:predicttotal:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(predicttotalService.selectPredicttotalById(id));
    }

    /**
     * 新增predicttotal
     */
    @PreAuthorize("@ss.hasPermi('predicttotal:predicttotal:add')")
    @Log(title = "predicttotal", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Predicttotal predicttotal)
    {
        return toAjax(predicttotalService.insertPredicttotal(predicttotal));
    }

    /**
     * 修改predicttotal
     */
    @PreAuthorize("@ss.hasPermi('predicttotal:predicttotal:edit')")
    @Log(title = "predicttotal", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Predicttotal predicttotal)
    {
        return toAjax(predicttotalService.updatePredicttotal(predicttotal));
    }

    /**
     * 删除predicttotal
     */
    @PreAuthorize("@ss.hasPermi('predicttotal:predicttotal:remove')")
    @Log(title = "predicttotal", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(predicttotalService.deletePredicttotalByIds(ids));
    }
}
