package com.enteprise.predictyear.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.predictyear.domain.Predictyear;
import com.enteprise.predictyear.service.IPredictyearService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * predictyearController
 * 
 * @author ruoyi
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/predictyear/predictyear")
public class PredictyearController extends BaseController
{
    @Autowired
    private IPredictyearService predictyearService;

    /**
     * 查询predictyear列表
     */
    @PreAuthorize("@ss.hasPermi('predictyear:predictyear:list')")
    @GetMapping("/list")
    public TableDataInfo list(Predictyear predictyear)
    {
        startPage();
        List<Predictyear> list = predictyearService.selectPredictyearList(predictyear);
        return getDataTable(list);
    }

    /**
     * 导出predictyear列表
     */
    @PreAuthorize("@ss.hasPermi('predictyear:predictyear:export')")
    @Log(title = "predictyear", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Predictyear predictyear)
    {
        List<Predictyear> list = predictyearService.selectPredictyearList(predictyear);
        ExcelUtil<Predictyear> util = new ExcelUtil<Predictyear>(Predictyear.class);
        util.exportExcel(response, list, "predictyear数据");
    }

    /**
     * 获取predictyear详细信息
     */
    @PreAuthorize("@ss.hasPermi('predictyear:predictyear:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(predictyearService.selectPredictyearById(id));
    }

    /**
     * 新增predictyear
     */
    @PreAuthorize("@ss.hasPermi('predictyear:predictyear:add')")
    @Log(title = "predictyear", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Predictyear predictyear)
    {
        return toAjax(predictyearService.insertPredictyear(predictyear));
    }

    /**
     * 修改predictyear
     */
    @PreAuthorize("@ss.hasPermi('predictyear:predictyear:edit')")
    @Log(title = "predictyear", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Predictyear predictyear)
    {
        return toAjax(predictyearService.updatePredictyear(predictyear));
    }

    /**
     * 删除predictyear
     */
    @PreAuthorize("@ss.hasPermi('predictyear:predictyear:remove')")
    @Log(title = "predictyear", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(predictyearService.deletePredictyearByIds(ids));
    }
}
