package com.enteprise.priceindex.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.enteprise.etype.domain.EnterpriseType;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.priceindex.domain.PriceIndex;
import com.enteprise.priceindex.service.IPriceIndexService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * priceindexController
 * 
 * @author ljx
 * @date 2025-02-07
 */
@RestController
@RequestMapping("/priceindex/priceindex")
public class PriceIndexController extends BaseController
{
    @Autowired
    private IPriceIndexService priceIndexService;

    /**
     * 查询priceindex列表
     */
    @PreAuthorize("@ss.hasPermi('priceindex:priceindex:list')")
    @GetMapping("/list")
    public TableDataInfo list(PriceIndex priceIndex)
    {
        startPage();
        List<PriceIndex> list = priceIndexService.selectPriceIndexList(priceIndex);
        return getDataTable(list);
    }

    /**
     * 导出priceindex列表
     */
    @PreAuthorize("@ss.hasPermi('priceindex:priceindex:export')")
    @Log(title = "priceindex", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PriceIndex priceIndex)
    {
        List<PriceIndex> list = priceIndexService.selectPriceIndexList(priceIndex);
        ExcelUtil<PriceIndex> util = new ExcelUtil<PriceIndex>(PriceIndex.class);
        util.exportExcel(response, list, "priceindex数据");
    }

    /**
     * 获取priceindex详细信息
     */
    @PreAuthorize("@ss.hasPermi('priceindex:priceindex:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(priceIndexService.selectPriceIndexById(id));
    }

    /**
     * 新增priceindex
     */
    @PreAuthorize("@ss.hasPermi('priceindex:priceindex:add')")
    @Log(title = "priceindex", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PriceIndex priceIndex)
    {
        return toAjax(priceIndexService.insertPriceIndex(priceIndex));
    }

    /**
     * 修改priceindex
     */
    @PreAuthorize("@ss.hasPermi('priceindex:priceindex:edit')")
    @Log(title = "priceindex", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PriceIndex priceIndex)
    {
        return toAjax(priceIndexService.updatePriceIndex(priceIndex));
    }

    /**
     * 删除priceindex
     */
    @PreAuthorize("@ss.hasPermi('priceindex:priceindex:remove')")
    @Log(title = "priceindex", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(priceIndexService.deletePriceIndexByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("导入价格指数")
    @Log(title = "价格指数", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('priceindex:priceindex:add')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file) throws Exception {
        // 获取模板工具
        ExcelUtil<PriceIndex> util = new ExcelUtil<>(PriceIndex.class);
        List<PriceIndex> list = util.importExcel(file.getInputStream());
        if (list.isEmpty()) {
            return error("数据不得为空");
        }
        boolean result = priceIndexService.batchTbPriceIndex(list);
        return result ? success() : error();
    }

    @ApiOperation("价格指数模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<PriceIndex> util = new ExcelUtil<>(PriceIndex.class);
        util.importTemplateExcel(response, "价格指数数据");
    }
}
