package com.enteprise.priceindex.service.impl;

import java.util.List;

import com.enteprise.etype.domain.EnterpriseType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.enteprise.priceindex.mapper.PriceIndexMapper;
import com.enteprise.priceindex.domain.PriceIndex;
import com.enteprise.priceindex.service.IPriceIndexService;

/**
 * priceindexService业务层处理
 * 
 * @author ljx
 * @date 2025-02-07
 */
@Service
public class PriceIndexServiceImpl implements IPriceIndexService 
{
    @Autowired
    private PriceIndexMapper priceIndexMapper;

    /**
     * 查询priceindex
     * 
     * @param id priceindex主键
     * @return priceindex
     */
    @Override
    public PriceIndex selectPriceIndexById(Long id)
    {
        return priceIndexMapper.selectPriceIndexById(id);
    }

    /**
     * 查询priceindex列表
     * 
     * @param priceIndex priceindex
     * @return priceindex
     */
    @Override
    public List<PriceIndex> selectPriceIndexList(PriceIndex priceIndex)
    {
        return priceIndexMapper.selectPriceIndexList(priceIndex);
    }

    /**
     * 新增priceindex
     * 
     * @param priceIndex priceindex
     * @return 结果
     */
    @Override
    public int insertPriceIndex(PriceIndex priceIndex)
    {
        return priceIndexMapper.insertPriceIndex(priceIndex);
    }

    @Override
    public boolean batchTbPriceIndex(List<PriceIndex> list) {
        //校验数据
        for (PriceIndex PriceIndex : list) {
            if (PriceIndex.getId() == null || PriceIndex.getName() == null) {
                throw new RuntimeException("代码或名称为空！");
            }
            // 检查数据库是否已存在相同ID
            PriceIndex exist = priceIndexMapper.selectPriceIndexById(PriceIndex.getId());
            if (exist != null) {
                throw new RuntimeException("代码 " + PriceIndex.getId() + " 已存在！");
            }
        }
        //批量导入
        priceIndexMapper.insertBatch(list);
        return false;
    }

    /**
     * 修改priceindex
     * 
     * @param priceIndex priceindex
     * @return 结果
     */
    @Override
    public int updatePriceIndex(PriceIndex priceIndex)
    {
        return priceIndexMapper.updatePriceIndex(priceIndex);
    }

    /**
     * 批量删除priceindex
     * 
     * @param ids 需要删除的priceindex主键
     * @return 结果
     */
    @Override
    public int deletePriceIndexByIds(Long[] ids)
    {
        return priceIndexMapper.deletePriceIndexByIds(ids);
    }

    /**
     * 删除priceindex信息
     * 
     * @param id priceindex主键
     * @return 结果
     */
    @Override
    public int deletePriceIndexById(Long id)
    {
        return priceIndexMapper.deletePriceIndexById(id);
    }
}
