package com.enteprise.run_data_month.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.run_data_month.domain.EnterpriseRunDataMonth;
import com.enteprise.run_data_month.service.IEnterpriseRunDataMonthService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * run_data_monthController
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/run_data_month/run_data_month")
public class EnterpriseRunDataMonthController extends BaseController
{
    @Autowired
    private IEnterpriseRunDataMonthService enterpriseRunDataMonthService;

    /**
     * 查询run_data_month列表
     */
    @PreAuthorize("@ss.hasPermi('run_data_month:run_data_month:list')")
    @GetMapping("/list")
    public TableDataInfo list(EnterpriseRunDataMonth enterpriseRunDataMonth)
    {
        startPage();
        List<EnterpriseRunDataMonth> list = enterpriseRunDataMonthService.selectEnterpriseRunDataMonthList(enterpriseRunDataMonth);
        return getDataTable(list);
    }

    /**
     * 导出run_data_month列表
     */
    @PreAuthorize("@ss.hasPermi('run_data_month:run_data_month:export')")
    @Log(title = "run_data_month", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EnterpriseRunDataMonth enterpriseRunDataMonth)
    {
        List<EnterpriseRunDataMonth> list = enterpriseRunDataMonthService.selectEnterpriseRunDataMonthList(enterpriseRunDataMonth);
        ExcelUtil<EnterpriseRunDataMonth> util = new ExcelUtil<EnterpriseRunDataMonth>(EnterpriseRunDataMonth.class);
        util.exportExcel(response, list, "run_data_month数据");
    }

    /**
     * 获取run_data_month详细信息
     */
    @PreAuthorize("@ss.hasPermi('run_data_month:run_data_month:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseRunDataMonthService.selectEnterpriseRunDataMonthById(id));
    }

    /**
     * 新增run_data_month
     */
    @PreAuthorize("@ss.hasPermi('run_data_month:run_data_month:add')")
    @Log(title = "run_data_month", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EnterpriseRunDataMonth enterpriseRunDataMonth)
    {
        return toAjax(enterpriseRunDataMonthService.insertEnterpriseRunDataMonth(enterpriseRunDataMonth));
    }

    /**
     * 修改run_data_month
     */
    @PreAuthorize("@ss.hasPermi('run_data_month:run_data_month:edit')")
    @Log(title = "run_data_month", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EnterpriseRunDataMonth enterpriseRunDataMonth)
    {
        return toAjax(enterpriseRunDataMonthService.updateEnterpriseRunDataMonth(enterpriseRunDataMonth));
    }

    /**
     * 删除run_data_month
     */
    @PreAuthorize("@ss.hasPermi('run_data_month:run_data_month:remove')")
    @Log(title = "run_data_month", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseRunDataMonthService.deleteEnterpriseRunDataMonthByIds(ids));
    }
}
