package com.enteprise.run_data_year.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.run_data_year.domain.EnterpriseRunDataYear;
import com.enteprise.run_data_year.service.IEnterpriseRunDataYearService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * run_data_yearController
 * 
 * @author ruoyi
 * @date 2024-08-30
 */
@RestController
@RequestMapping("/run_data_year/run_data_year")
public class EnterpriseRunDataYearController extends BaseController
{
    @Autowired
    private IEnterpriseRunDataYearService enterpriseRunDataYearService;

    /**
     * 查询run_data_year列表
     */
    @PreAuthorize("@ss.hasPermi('run_data_year:run_data_year:list')")
    @GetMapping("/list")
    public TableDataInfo list(EnterpriseRunDataYear enterpriseRunDataYear)
    {
        startPage();
        List<EnterpriseRunDataYear> list = enterpriseRunDataYearService.selectEnterpriseRunDataYearList(enterpriseRunDataYear);
        return getDataTable(list);
    }

    /**
     * 导出run_data_year列表
     */
    @PreAuthorize("@ss.hasPermi('run_data_year:run_data_year:export')")
    @Log(title = "run_data_year", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EnterpriseRunDataYear enterpriseRunDataYear)
    {
        List<EnterpriseRunDataYear> list = enterpriseRunDataYearService.selectEnterpriseRunDataYearList(enterpriseRunDataYear);
        ExcelUtil<EnterpriseRunDataYear> util = new ExcelUtil<EnterpriseRunDataYear>(EnterpriseRunDataYear.class);
        util.exportExcel(response, list, "run_data_year数据");
    }

    /**
     * 获取run_data_year详细信息
     */
    @PreAuthorize("@ss.hasPermi('run_data_year:run_data_year:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseRunDataYearService.selectEnterpriseRunDataYearById(id));
    }

    /**
     * 新增run_data_year
     */
    @PreAuthorize("@ss.hasPermi('run_data_year:run_data_year:add')")
    @Log(title = "run_data_year", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EnterpriseRunDataYear enterpriseRunDataYear)
    {
        return toAjax(enterpriseRunDataYearService.insertEnterpriseRunDataYear(enterpriseRunDataYear));
    }

    /**
     * 修改run_data_year
     */
    @PreAuthorize("@ss.hasPermi('run_data_year:run_data_year:edit')")
    @Log(title = "run_data_year", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EnterpriseRunDataYear enterpriseRunDataYear)
    {
        return toAjax(enterpriseRunDataYearService.updateEnterpriseRunDataYear(enterpriseRunDataYear));
    }

    /**
     * 删除run_data_year
     */
    @PreAuthorize("@ss.hasPermi('run_data_year:run_data_year:remove')")
    @Log(title = "run_data_year", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseRunDataYearService.deleteEnterpriseRunDataYearByIds(ids));
    }
}
