package com.enteprise.season.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.season.domain.EnterpriseBaseDataSeason;
import com.enteprise.season.service.IEnterpriseBaseDataSeasonService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * seasonController
 * 
 * @author ruoyi
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/season/season")
public class EnterpriseBaseDataSeasonController extends BaseController
{
    @Autowired
    private IEnterpriseBaseDataSeasonService enterpriseBaseDataSeasonService;

    /**
     * 查询season列表
     */
    @PreAuthorize("@ss.hasPermi('season:season:list')")
    @GetMapping("/list")
    public TableDataInfo list(EnterpriseBaseDataSeason enterpriseBaseDataSeason)
    {
        startPage();
        List<EnterpriseBaseDataSeason> list = enterpriseBaseDataSeasonService.selectEnterpriseBaseDataSeasonList(enterpriseBaseDataSeason);
        return getDataTable(list);
    }

    /**
     * 导出season列表
     */
    @PreAuthorize("@ss.hasPermi('season:season:export')")
    @Log(title = "season", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EnterpriseBaseDataSeason enterpriseBaseDataSeason)
    {
        List<EnterpriseBaseDataSeason> list = enterpriseBaseDataSeasonService.selectEnterpriseBaseDataSeasonList(enterpriseBaseDataSeason);
        ExcelUtil<EnterpriseBaseDataSeason> util = new ExcelUtil<EnterpriseBaseDataSeason>(EnterpriseBaseDataSeason.class);
        util.exportExcel(response, list, "season数据");
    }

    /**
     * 获取season详细信息
     */
    @PreAuthorize("@ss.hasPermi('season:season:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseBaseDataSeasonService.selectEnterpriseBaseDataSeasonById(id));
    }

    /**
     * 新增season
     */
    @PreAuthorize("@ss.hasPermi('season:season:add')")
    @Log(title = "season", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EnterpriseBaseDataSeason enterpriseBaseDataSeason)
    {
        return toAjax(enterpriseBaseDataSeasonService.insertEnterpriseBaseDataSeason(enterpriseBaseDataSeason));
    }

    /**
     * 修改season
     */
    @PreAuthorize("@ss.hasPermi('season:season:edit')")
    @Log(title = "season", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EnterpriseBaseDataSeason enterpriseBaseDataSeason)
    {
        return toAjax(enterpriseBaseDataSeasonService.updateEnterpriseBaseDataSeason(enterpriseBaseDataSeason));
    }

    /**
     * 删除season
     */
    @PreAuthorize("@ss.hasPermi('season:season:remove')")
    @Log(title = "season", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseBaseDataSeasonService.deleteEnterpriseBaseDataSeasonByIds(ids));
    }
}
