package com.enteprise.uploadfile.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.enteprise.common.annotation.Log;
import com.enteprise.common.core.controller.BaseController;
import com.enteprise.common.core.domain.AjaxResult;
import com.enteprise.common.enums.BusinessType;
import com.enteprise.uploadfile.domain.Uploadfile;
import com.enteprise.uploadfile.service.IUploadfileService;
import com.enteprise.common.utils.poi.ExcelUtil;
import com.enteprise.common.core.page.TableDataInfo;

/**
 * uploadfileController
 * 
 * @author ruoyi
 * @date 2024-09-16
 */
@RestController
@RequestMapping("/uploadfile/uploadfile")
public class UploadfileController extends BaseController
{
    @Autowired
    private IUploadfileService uploadfileService;

    /**
     * 查询uploadfile列表
     */
    @PreAuthorize("@ss.hasPermi('uploadfile:uploadfile:list')")
    @GetMapping("/list")
    public TableDataInfo list(Uploadfile uploadfile)
    {
        startPage();
        List<Uploadfile> list = uploadfileService.selectUploadfileList(uploadfile);
        return getDataTable(list);
    }

    /**
     * 导出uploadfile列表
     */
    @PreAuthorize("@ss.hasPermi('uploadfile:uploadfile:export')")
    @Log(title = "uploadfile", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Uploadfile uploadfile)
    {
        List<Uploadfile> list = uploadfileService.selectUploadfileList(uploadfile);
        ExcelUtil<Uploadfile> util = new ExcelUtil<Uploadfile>(Uploadfile.class);
        util.exportExcel(response, list, "uploadfile数据");
    }

    /**
     * 获取uploadfile详细信息
     */
    @PreAuthorize("@ss.hasPermi('uploadfile:uploadfile:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(uploadfileService.selectUploadfileById(id));
    }

    /**
     * 新增uploadfile
     */
    @PreAuthorize("@ss.hasPermi('uploadfile:uploadfile:add')")
    @Log(title = "uploadfile", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Uploadfile uploadfile)
    {
        return toAjax(uploadfileService.insertUploadfile(uploadfile));
    }

    /**
     * 修改uploadfile
     */
    @PreAuthorize("@ss.hasPermi('uploadfile:uploadfile:edit')")
    @Log(title = "uploadfile", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Uploadfile uploadfile)
    {
        return toAjax(uploadfileService.updateUploadfile(uploadfile));
    }

    /**
     * 删除uploadfile
     */
    @PreAuthorize("@ss.hasPermi('uploadfile:uploadfile:remove')")
    @Log(title = "uploadfile", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(uploadfileService.deleteUploadfileByIds(ids));
    }
}
